require 'i18n'
require 'headless'
require 'capybara'
require 'capybara-webkit'
require 'capybara/dsl'
require 'capybara/cucumber'
require 'capybara/poltergeist'
require 'capybara-screenshot'
require 'capybara-screenshot/cucumber'
require 'rspec/expectations'
require 'site_prism'
require 'yaml'
require 'cuculungwa/generators'
require 'cuculungwa/utils'
require 'cuculungwa/formatters'

config = YAML.load(File.open('config/config.yml'))
config.merge!(YAML.load(File.open(ENV['CONFIG']))) if ENV['CONFIG']
config['project']['default_host'] = config['project'][ENV['PROJECT'] || 'development']
config['framework']['i18n']['locale'] = ENV['LOCALE'] || config['framework']['i18n']['locale']

I18n.enforce_available_locales = false
I18n.locale = config['framework']['i18n']['locale'].to_sym
I18n.load_path = Dir[config['framework']['i18n']['load_path']]

if config['capybara']['browser'] == 'phantomjs'
  Capybara.register_driver :poltergeist do |app|
    Capybara::Poltergeist::Driver.new app,
                                      phantomjs_options: config['capybara']['phantomjs_specific']['options'],
                                      window_size: config['capybara']['phantomjs_specific']['window_size']
  end
  Capybara.default_driver = :poltergeist
elsif config['capybara']['browser'] == 'capybara-webkit'
  headless = Headless.new
  headless.start
  Capybara.default_driver = :webkit
elsif config['capybara']['browser'] == 'seleniumRC'
  require 'selenium-webdriver'
  client = Selenium::WebDriver::Remote::Http::Default.new
  client.timeout = ENV['CLIENT_TIMEOUT'] ? ENV['CLIENT_TIMEOUT'].to_i : 60
  capabilities = Selenium::WebDriver::Remote::Capabilities.new
  capabilities[:introduce_flakiness_by_ignoring_security_domains] = true
  capabilities[:javascript_enabled] = true
  capabilities[:css_selectors_enabled] = true
  capabilities[:ignore_protected_mode_settings] = true
  Capybara.register_driver :selenium do |app|
    Capybara::Selenium::Driver.new(app, browser: :remote, url: config['capybara']['seleniumRC_specific']['hub'], http_client: client, desired_capabilities: capabilities)
  end
  Capybara.default_driver = :selenium
else
  Capybara.register_driver :selenium do |app|
    Capybara::Selenium::Driver.new(app, browser: config['capybara']['browser'].to_sym)
  end
  Capybara.default_driver = :selenium
end

Capybara.save_path = config['capybara']['save_and_open_page_path'] || config['capybara']['save_path']
Capybara.app_host = config['project']['default_host']['front']
Capybara.default_max_wait_time = 1

World(Capybara)
