module Utils
  def click(element)
    if @app.config['capybara']['browser'] == 'phantomjs'
      element.trigger('click')
    else
      element.click
    end
  end

  def set_app(app)
    Capybara.app_host = @app.config['project']['default_host'][app]
  end

  def set_environment_and_app(environment, app)
    Capybara.app_host = @app.config['project'][environment][app]
  end

  def wait_for_expected_result(timespan = @app.config['capybara']['default_wait_time'], exception_type = RSpec::Expectations::ExpectationNotMetError)
    # Default setting: get default wait time from config.yml
    start_time = Time.now
    loop do
      begin
        yield
        break
      rescue exception_type => e
        # Expectations were not met, check if we timed out, otherwise try one more time after 10ms
        if Time.now > start_time + timespan
          puts 'Timeout.'
          raise e
        end
        sleep 0.01
      end
    end
    # for debug purpose
    # puts "Waiting for expected result took #{Time.now - _then}s."
  end

  def I18n_first(text)
    text = I18n.t(text, raise: I18n::MissingTranslationData)
    return text
  rescue I18n::MissingTranslationData
    return text
  end

  def wait_for_ajax
    sleep 1
    Timeout.timeout(Capybara.default_wait_time, Timeout::Error) do
      loop until finished_all_ajax_requests?
    end
  end

  def finished_all_ajax_requests?
    page.evaluate_script('jQuery.active').zero?
  end
end

World(Utils)
